# FixedIncome
Python Fixed Income Securities &amp; Derivatives analytics package, originally written for [15.438 Fixed Income Securities &amp; Derivatives](http://student.mit.edu/catalog/m15b.html#15.438) at the MIT Sloan School of Management.

## Installation
Installation is done through PIP; enter the following on the command line:
```bash
$ pip3 install fixedincome-analytics
```